==> qink_0.3.1.orig.tar.gz: qink-0.3.1/locale/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ru_RU">
<context>
    <name>@default</name>
    <message>
        <location filename="" line="7471221"/>
        <source>language_name</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>A Qt Printer Ink Level Monitor Utility&lt;br /&gt;&lt;br /&gt;Copyright (C) 2003 Moris Ravasio &amp;lt;moris_ravasio@hotmail.com&amp;gt;&lt;br /&gt;Copyright (C) 2007 Matvey Kozhev &amp;lt;sikon@lucidfox.org&amp;gt;</source>
        <translation>Утилита мониторинга уровня чернил для Qt&lt;br /&gt;&lt;br /&gt;Copyright (C) 2003 Moris Ravasio &amp;lt;moris_ravasio@hotmail.com&amp;gt;&lt;br /&gt;Copyright (C) 2007 Matvey Kozhev &amp;lt;sikon@lucidfox.org&amp;gt;</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <location filename="" line="7471221"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Authors</source>
        <translation>Авторы</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Thanks To</source>
        <translation>Благодарность</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Translation</source>
        <translation>Перевод</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>About %1</source>
        <translation>О программе %1</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="" line="7471221"/>
        <source>Unsupported device</source>
        <translation>Неизвестное устройство</translation>
    </message>
</context>
<context>
    <name>QInkDlg</name>
    <message>
        <location filename="" line="7471221"/>
        <source>QInk</source>
        <translation>QInk</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Select a printer:</source>
        <translation>Выберите принтер:</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&amp;Detect</source>
        <translation>Об&amp;наружение</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Alt+D</source>
        <translation>Alt-Н</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;&lt;font size=&quot;+3&quot;&gt;Printer error&lt;/font&gt;&lt;/b&gt;</source>
        <translation>&lt;b&gt;&lt;font size=&quot;+3&quot;&gt;Ошибка принтера&lt;/font&gt;&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>[Here is the place for a description of the error that has occured]</source>
        <translation>[Описание ошибки]</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Black</source>
        <translation>Чёрный</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;Black:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Чёрный:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Colors</source>
        <translation>Цвета</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;Yellow:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Жёлтый:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;Magenta:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Пурпурный:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;Cyan:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Голубой:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;Color:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Цвет:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Cyan</source>
        <translation>Голубой</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Magenta</source>
        <translation>Пурпурный</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Yellow</source>
        <translation>Жёлтый</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Photo colors</source>
        <translation>Фото-цвета</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Photo color</source>
        <translation>Фото-цвет</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Photo cyan</source>
        <translation>Фото-голубой</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Photo magenta</source>
        <translation>Фото-пурпурный</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Photo yellow</source>
        <translation>Фото-жёлтый</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&amp;About...</source>
        <translation>О &amp;программе...</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Alt+A</source>
        <translation>Alt-П</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&amp;Update</source>
        <translation>&amp;Обновить</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Alt+U</source>
        <translation>Alt-О</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>Alt+C</source>
        <translation>Alt-З</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&amp;Show/hide</source>
        <translation>&amp;Показать/скрыть</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&amp;Exit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;No printers detected on this system&lt;/b&gt;&lt;br&gt;&lt;br&gt;It seems that there are no printer plugged to this computer. Please verify the connections of your devices; maybe a problem of wrong permissions on the device&apos;s port.&lt;br&gt;&lt;br&gt;For parallel printers try &lt;b&gt;chmod 666 /dev/lpX&lt;/b&gt; and &lt;br&gt;&lt;b&gt;chmod 666 /dev/parportX&lt;/b&gt; (as root), where X is your printer&apos;s parallel port number.&lt;br&gt;&lt;br&gt;For USB printers, try &lt;b&gt;chmod 666 /dev/usblpX&lt;/b&gt; (as root), where X is your printer&apos;s USB port number.&lt;br&gt;&lt;br&gt;Click on &lt;b&gt;Detect&lt;/b&gt; to try again.</source>
        <translation>&lt;b&gt;Принтеры не найдены&lt;/b&gt;&lt;br&gt;&lt;br&gt;Похоже, что к этому компьютеру не подключено ни одного принтера. Проверьте подключение и права доступа к файлам устройств.&lt;br&gt;&lt;br&gt;Для параллельных портов попробуйте выполнить &lt;b&gt;chmod 666 /dev/lpX&lt;/b&gt; и &lt;br&gt;&lt;b&gt;chmod 666 /dev/parportX&lt;/b&gt; (как root), где X - номер параллельного порта вашего принтера.&lt;br&gt;&lt;br&gt;Для USB принтеров попробуйте выполнить &lt;b&gt;chmod 666 /dev/usblpX&lt;/b&gt; (как root), где X - номер USB-порта принтера.&lt;br&gt;&lt;br&gt;Затем нажмите &lt;b&gt;Обнаружение&lt;/b&gt;, чтобы попытаться снова.</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;Generic error&lt;/b&gt;&lt;br&gt;&lt;br&gt;An error has occured communicating with the selected device. Click &lt;b&gt;Detect&lt;/b&gt; and &lt;b&gt;Update&lt;/b&gt; to refresh QInkDlg status and try again. If the problem persists, e-mail me a description of the situation and all that can be helpful to me for reconstructing your execution environment.</source>
        <translation type="obsolete">&lt;b&gt;Общая ошибка&lt;/b&gt;&lt;br&gt;&lt;br&gt;При соединении с выбранным устройством возникла ошибка. Нажмите &lt;b&gt;Обнаружение&lt;/b&gt; и &lt;b&gt;Обновить&lt;/b&gt;, чтобы попытаться снова. Если проблема не исчезнет, свяжитесь с разработчиком программы.</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;Cannot read ink level from device&lt;/b&gt;&lt;br&gt;&lt;br&gt;Cannot retrieve ink levels from the selected device. Ensure your printer is switched on and click on &lt;b&gt;Update&lt;/b&gt; to try again.</source>
        <translation>&lt;b&gt;Невозможно получить уровень чернил от устройства&lt;/b&gt;&lt;br&gt;&lt;br&gt;Не удалось получить уровень чернил от выбранного устройства. Убедитесь, что принтер подключён, и нажмите &lt;b&gt;Обновить&lt;/b&gt;, чтобы попытаться снова.</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;Unsupported printer!&lt;/b&gt;&lt;br&gt;&lt;br&gt;Selected printer is not supported by this version of libinklevel. Take a look to &lt;a href=&apos;http://home.arcor.de/markusheinz&apos;&gt;http://home.arcor.de/markusheinz&lt;/a&gt; for a complete list of devices supported by your version of libinklevel.</source>
        <translation>&lt;b&gt;Принтер не поддерживается!&lt;/b&gt;&lt;br&gt;&lt;br&gt;Выбранный принтер не поддерживается этой версией libinklevel. Посетите Web-сайт библиотеки &lt;a href=&apos;http://libinklevel.sourceforge.net/&apos;&gt;http://libinklevel.sourceforge.net/&lt;/a&gt;, чтобы получить полный список поддерживаемых устройств.</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>&lt;b&gt;Generic error&lt;/b&gt;&lt;br&gt;&lt;br&gt;An error has occured communicating with the selected device. Click &lt;b&gt;Detect&lt;/b&gt; and &lt;b&gt;Update&lt;/b&gt; to refresh QInk status and try again. If the problem persists, e-mail me a description of the situation and all that can be helpful to me for reconstructing your execution environment.</source>
        <translation>&lt;b&gt;Общая ошибка&lt;/b&gt;&lt;br&gt;&lt;br&gt;При соединении с выбранным устройством возникла ошибка. Нажмите &lt;b&gt;Обнаружение&lt;/b&gt; и &lt;b&gt;Обновить&lt;/b&gt;, чтобы попытаться снова. Если проблема не исчезнет, свяжитесь с разработчиком программы.</translation>
    </message>
    <message>
        <location filename="" line="7471221"/>
        <source>%1: %2%
</source>
        <translation>%1: %2%
</translation>
    </message>
</context>
</TS>

==> qink_0.3.5.orig.tar.gz: qink-0.3.5/locale/ru.ts <==
<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name>@default</name>
    <message>
        <source>language_name</source>
        <translation>Русский</translation>
    </message>
    <message>
        <source>A Qt Printer Ink Level Monitor Utility&lt;br /&gt;&lt;br /&gt;Copyright (C) 2003 Moris Ravasio &amp;lt;moris_ravasio@hotmail.com&amp;gt;&lt;br /&gt;Copyright (C) 2007 Matvey Kozhev &amp;lt;sikon@lucidfox.org&amp;gt;</source>
        <translation>Утилита мониторинга уровня чернил для Qt&lt;br /&gt;&lt;br /&gt;Copyright (C) 2003 Moris Ravasio &amp;lt;moris_ravasio@hotmail.com&amp;gt;&lt;br /&gt;Copyright (C) 2007 Matvey Kozhev &amp;lt;sikon@lucidfox.org&amp;gt;</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Авторы</translation>
    </message>
    <message>
        <source>Thanks To</source>
        <translation>Благодарность</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Перевод</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>О программе %1</translation>
    </message>
    <message>
        <source>translated_by</source>
        <translation>Matvey Kozhev &lt;sikon@lucidfox.org&gt;</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unsupported device</source>
        <translation>Неизвестное устройство</translation>
    </message>
</context>
<context>
    <name>QInkDlg</name>
    <message>
        <source>QInk</source>
        <translation>QInk</translation>
    </message>
    <message>
        <source>Select a printer:</source>
        <translation>Выберите принтер:</translation>
    </message>
    <message>
        <source>&amp;Detect</source>
        <translation>Об&amp;наружение</translation>
    </message>
    <message>
        <source>Alt+D</source>
        <translation>Alt-Н</translation>
    </message>
    <message>
        <source>&lt;b&gt;&lt;font size=&quot;+3&quot;&gt;Printer error&lt;/font&gt;&lt;/b&gt;</source>
        <translation>&lt;b&gt;&lt;font size=&quot;+3&quot;&gt;Ошибка принтера&lt;/font&gt;&lt;/b&gt;</translation>
    </message>
    <message>
        <source>[Here is the place for a description of the error that has occured]</source>
        <translation>[Описание ошибки]</translation>
    </message>
    <message>
        <source>Black</source>
        <translation>Чёрный</translation>
    </message>
    <message>
        <source>&lt;b&gt;Black:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Чёрный:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Цвета</translation>
    </message>
    <message>
        <source>&lt;b&gt;Yellow:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Жёлтый:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Magenta:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Пурпурный:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Cyan:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Голубой:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Color:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Цвет:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Цвет</translation>
    </message>
    <message>
        <source>Cyan</source>
        <translation>Голубой</translation>
    </message>
    <message>
        <source>Magenta</source>
        <translation>Пурпурный</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Жёлтый</translation>
    </message>
    <message>
        <source>Photo colors</source>
        <translation>Фото-цвета</translation>
    </message>
    <message>
        <source>Photo color</source>
        <translation>Фото-цвет</translation>
    </message>
    <message>
        <source>Photo cyan</source>
        <translation>Фото-голубой</translation>
    </message>
    <message>
        <source>Photo magenta</source>
        <translation>Фото-пурпурный</translation>
    </message>
    <message>
        <source>Photo yellow</source>
        <translation>Фото-жёлтый</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt-П</translation>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>&amp;Обновить</translation>
    </message>
    <message>
        <source>Alt+U</source>
        <translation>Alt-О</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt-З</translation>
    </message>
    <message>
        <source>&amp;Show/hide</source>
        <translation>&amp;Показать/скрыть</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>&amp;Exit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>&lt;b&gt;Cannot read ink level from device&lt;/b&gt;&lt;br&gt;&lt;br&gt;Cannot retrieve ink levels from the selected device. Ensure your printer is switched on and click on &lt;b&gt;Update&lt;/b&gt; to try again.</source>
        <translation>&lt;b&gt;Невозможно получить уровень чернил от устройства&lt;/b&gt;&lt;br&gt;&lt;br&gt;Не удалось получить уровень чернил от выбранного устройства. Убедитесь, что принтер подключён, и нажмите &lt;b&gt;Обновить&lt;/b&gt;, чтобы попытаться снова.</translation>
    </message>
    <message>
        <source>&lt;b&gt;Unsupported printer!&lt;/b&gt;&lt;br&gt;&lt;br&gt;Selected printer is not supported by this version of libinklevel. Take a look to &lt;a href=&apos;http://home.arcor.de/markusheinz&apos;&gt;http://home.arcor.de/markusheinz&lt;/a&gt; for a complete list of devices supported by your version of libinklevel.</source>
        <translation>&lt;b&gt;Принтер не поддерживается!&lt;/b&gt;&lt;br&gt;&lt;br&gt;Выбранный принтер не поддерживается этой версией libinklevel. Посетите Web-сайт библиотеки &lt;a href=&apos;http://libinklevel.sourceforge.net/&apos;&gt;http://libinklevel.sourceforge.net/&lt;/a&gt;, чтобы получить полный список поддерживаемых устройств.</translation>
    </message>
    <message>
        <source>&lt;b&gt;Generic error&lt;/b&gt;&lt;br&gt;&lt;br&gt;An error has occured communicating with the selected device. Click &lt;b&gt;Detect&lt;/b&gt; and &lt;b&gt;Update&lt;/b&gt; to refresh QInk status and try again. If the problem persists, e-mail me a description of the situation and all that can be helpful to me for reconstructing your execution environment.</source>
        <translation>&lt;b&gt;Общая ошибка&lt;/b&gt;&lt;br&gt;&lt;br&gt;При соединении с выбранным устройством возникла ошибка. Нажмите &lt;b&gt;Обнаружение&lt;/b&gt; и &lt;b&gt;Обновить&lt;/b&gt;, чтобы попытаться снова. Если проблема не исчезнет, свяжитесь с разработчиком программы.</translation>
    </message>
    <message>
        <source>%1: %2%
</source>
        <translation>%1: %2%
</translation>
    </message>
    <message>
        <source>Photo black</source>
        <translation>Фото-чёрный</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>QInk: No printers detected</source>
        <translation>QInk: Принтеры не обнаружены</translation>
    </message>
    <message>
        <source>QInk: Printer error, double click for details</source>
        <translation>QInk: Ошибка принтера, щёлкните дважды для вывода подробностей</translation>
    </message>
    <message>
        <source>&lt;b&gt;No printers detected on this system&lt;/b&gt;&lt;br /&gt;&lt;br /&gt; It seems that there are no printer plugged to this computer. Please verify the connections of your devices. You may also not have the required permissions to access the printer device file.&lt;br /&gt;&lt;br /&gt;Try adding yourself to the &lt;b&gt;lp&lt;/b&gt; user group using your system&apos;s administration utility or the &lt;b&gt;groupadd&lt;/b&gt; console command, and then log out and back in and restart QInk.&lt;br /&gt;&lt;br /&gt;Alternatively, you can run QInk as root.&lt;br /&gt;&lt;br /&gt;Click &lt;b&gt;Detect&lt;/b&gt; to try again.</source>
        <translation>&lt;b&gt;В системе не обнаружено принтеров&lt;/b&gt;&lt;br /&gt;&lt;br /&gt; По-видимому, к этому компьютеру не подсоединено ни одного принтера. Пожалуйста, проверьте подключение устройств. Также возможно, что у вас нет необходимых прав доступа к файлу устройства принтера.&lt;br /&gt;&lt;br /&gt;Попробуйте добавить себя в пользовательскую группу &lt;b&gt;lp&lt;/b&gt;, используя средство администрирования вашей системы или консольную команду &lt;b&gt;groupadd&lt;/b&gt;, после чего выйдите из системы, снова войдите в неё и перезапустите QInk.&lt;br /&gt;&lt;br /&gt;Вы также можете запустить QInk как root.&lt;br /&gt;&lt;br /&gt;Нажмите кнопку &lt;b&gt;Обнаружение&lt;/b&gt;, чтобы попытаться снова.</translation>
    </message>
</context>
</TS>
